# NekoBotAPI-py

NekoBot API Python Wrapper

## Getting Started

### Prerequisites

- Python3

### Installing

Install with pip

```shell
pip install nekobot
```

or install locally

```shell
git clone https://github.com/hibikidesu/NekoBotAPI-py.git
cd NekoBotAPI-py
python3 setup.py install
```

Examples are under the [examples](examples) directory
